@@ -61,7 +61,7 @@ class VCSCheckCommand(Command):
         else:
             args = [typed_eid(x) for x in args]
         for eid in args:
-            session.set_pool()
+            session.set_cnxset()
             vcsrepo = session.entity_from_eid(eid)
             assert vcsrepo.__regid__ == 'Repository', 'bad eid %s' % eid
             try:
