@@ -45,7 +45,7 @@ class Repository(AnyEntity):
     __regid__ ='Repository'
 
     __permissions__ = ('write',)
-    fetch_attrs, fetch_order = fetch_config(['source_url', 'title', 'subpath', 'type'])
+    fetch_attrs, cw_fetch_order = fetch_config(['source_url', 'title', 'subpath', 'type'])
     rest_attr = 'eid' # see #XXX, using path cause pb w/ apache redirection
 
     def dc_title(self):
@@ -62,8 +62,8 @@ class Repository(AnyEntity):
                 'type': self.type, 'eid': self.eid}
         return title
 
-    def clear_all_caches(self):
-        super(Repository, self).clear_all_caches()
+    def cw_clear_all_caches(self):
+        super(Repository, self).cw_clear_all_caches()
         clear_cache(self, 'branch_head')
 
     def printable_value(self, attr, *args, **kwargs):
@@ -184,7 +184,7 @@ class Repository(AnyEntity):
 class Revision(AnyEntity):
     """customized class for Revision entities"""
     __regid__ ='Revision'
-    fetch_attrs, fetch_order = fetch_config(['revision', 'changeset', 'branch',
+    fetch_attrs, cw_fetch_order = fetch_config(['revision', 'changeset', 'branch',
                                              'author', 'description', 'creation_date'],
                                             order='DESC')
 
@@ -225,7 +225,7 @@ class Revision(AnyEntity):
 class VersionedFile(AnyEntity):
     """customized class for VersionedFile entities"""
     __regid__ ='VersionedFile'
-    fetch_attrs, fetch_order = fetch_config(['directory', 'name'])
+    fetch_attrs, cw_fetch_order = fetch_config(['directory', 'name'])
 
     # XXX branches
     def dc_title(self):
@@ -242,8 +242,8 @@ class VersionedFile(AnyEntity):
             return self._cw._('%(path)s (from private repository)') % {
                 'path': self.dc_title(),}
 
-    def clear_all_caches(self):
-        super(VersionedFile, self).clear_all_caches()
+    def cw_clear_all_caches(self):
+        super(VersionedFile, self).cw_clear_all_caches()
         clear_cache(self, 'version_content')
         clear_cache(self, 'branch_head')
 
@@ -353,8 +353,8 @@ class VersionedFile(AnyEntity):
 class DeletedVersionContent(AnyEntity):
     """customized class for DeletedVersionContent entities"""
     __regid__ ='DeletedVersionContent'
-    fetch_attrs, fetch_order = fetch_config(['from_revision', 'content_for'],
-                                            order='DESC')
+    fetch_attrs, cw_fetch_order = fetch_config(['from_revision', 'content_for'],
+                                               order='DESC')
 
     def dc_title(self):
         return self._cw._('%(file)s DELETED') % {
