@@ -114,14 +114,16 @@ class VCSFileStartHook(hook.Hook):
 
     def __call__(self):
         repo = self.repo
-        def refresh_local_repo_caches(repo=repo, osp=osp, bridge=bridge):
+        rql = ('Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
+               'NOT (R local_cache NULL AND R path NULL),'
+               'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
+               'R import_revision_content RIRC')
+        if not repo.config['cache-external-repositories']:
+            rql += ', R cw_source S, S name "system"'
+        def refresh_local_repo_caches(repo=repo, osp=osp, bridge=bridge, rql=rql):
             session = repo.internal_session()
             try:
-                reposrset = session.execute(
-                    'Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
-                    'NOT (R local_cache NULL AND R path NULL),'
-                    'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
-                    'R import_revision_content RIRC, R cw_source S, S name "system"')
+                reposrset = session.execute(rql)
                 for vcsrepo in reposrset.entities():
                     # watch for repository being shut-down, our thread may:
                     # * not receive the KeyboardInterrupt or shutdown signal
@@ -149,7 +151,7 @@ class VCSFileStartHook(hook.Hook):
                             repohdlr.exception(
                                 'error while updating local cache of repository %s',
                                 vcsrepo.eid)
-                    if repo.config['repository-import']:
+                    if repo.config['repository-import'] and repo.cw_metainformation()['source']['uri'] == 'system':
                         bridge.import_vcsrepo_content(
                             session, repohdlr, vcsrepo,
                             commitevery=repo.config.get('check-revision-commit-every', 1))
