@@ -87,14 +87,14 @@ class HGRepository(repo.VCSRepository):
                 hgcmd.clone(vcsfile_ui(self), str(url),
                             dest=self.path, stream='compressed', noupdate=True)
             except (util.Abort, urllib2.URLError), ex:
-                raise bridge.VCSException(str(ex))
+                raise bridge.VCSException(self.eid, 'url', str(ex))
         else:
             self.info('pulling from %s into %s', remove_authinfo(url), self.path)
             vui = vcsfile_ui(self)
             try:
                 hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url))
             except (util.Abort, urllib2.URLError), ex:
-                raise bridge.VCSException(str(ex))
+                raise bridge.VCSException(self.eid, 'path', str(ex))
 
     def import_content(self, repoentity, commitevery=10):
         """import content from the mercurial repository"""
@@ -120,8 +120,9 @@ class HGRepository(repo.VCSRepository):
             self.warning('%s: strip detected ? latest known revision is %s, '
                          'latest repository revision is %s', self.path,
                          latestrev, actualrev)
-            session.execute('DELETE Revision X WHERE X revision > %(rev)s',
-                            {'rev': actualrev})
+            session.execute('DELETE Revision X WHERE X revision > %(rev)s,'
+                            'X from_repository R, R eid %(r)s',
+                            {'rev': actualrev, 'r': self.eid})
             return
         self.info('hg repo %s: known revisions up to %s, repo revision %s',
                   self.path, latestrev, actualrev)
@@ -133,10 +134,10 @@ class HGRepository(repo.VCSRepository):
                               i, self.path, exc_info=True)
                 raise
             if not i % commitevery:
-                # give a change to threads waiting for a pool by freeing it then
+                # give a change to threads waiting for a cnxset by freeing it then
                 # reacquiring it
                 session.commit()
-                session.set_pool()
+                session.set_cnxset()
 
     def import_revision(self, repoentity, repo, i):
         self.info('importing revision %s', i)
@@ -319,10 +320,10 @@ class HGRepository(repo.VCSRepository):
             else:
                 self.check_revision(repoentity, repo, i, stripidx)
             if not i % commitevery:
-                # give a change to threads waiting for a pool by freeing it then
+                # give a change to threads waiting for a cnxset by freeing it then
                 # reacquiring it
                 session.commit()
-                session.set_pool()
+                session.set_cnxset()
         if strip:
             if stripidx['Revision']:
                 self.warning('deleted %s revisions not in repository',
@@ -576,9 +577,9 @@ class HGTransaction(object):
             rev.cw_edited['changeset'] = unicode(short_hex(node))
             source.update_entity(self.session, rev)
         # we need to explicitly commit the connection to the database since this
-        # method is actually called from a postcommit event, i.e. once pool has
+        # method is actually called from a postcommit event, i.e. once cnxset has
         # already been commited
-        self.session.pool.connection('system').commit()
+        self.session.cnxset.connection('system').commit()
         # XXX restore entity's dict?
         self.rollback()
 
