@@ -45,7 +45,7 @@ class Repository(EntityType):
                   description=_('absolute path to the local repository'),
                   __permissions__=PRIVATE_ATTRPERMS)
     local_cache = String(unique=True,
-                         description=_('absolute path to the local cache of the repository'),
+                         description=_('relative path to the local cache of the repository'),
                          __permissions__=PRIVATE_ATTRPERMS)
     subpath = String(description=_('if specified, only import the given subpart'
                                    ' of the repository (path relative to the '
